#pragma once

#include "NWindowTimer.h"
#include "TipCommand.h"
#include "UpdaterModel.h"
#include "UpdaterDocument.h"
#include "CommandHelper.h"
#include "NPMessageHandler.h"
#include "MessageBox.h"

const int TIMER_NOTIFY_WINDOW_TIME = 1000;
const UINT	WM_RECEIVE_DS_REGNOTIFY	= (WM_APP + 10);
const UINT	WM_RECEIVE_SP_REGNOTIFY	= (WM_APP + 11);

struct TASKBAR_INFO
{
	enum TASKBAR_POS{ 
		LEFT		= ABE_LEFT,
		RIGHT		= ABE_RIGHT,
		TOP			= ABE_TOP,
		BOTTOM		= ABE_BOTTOM
	};

	TASKBAR_POS		position;
	MONITORINFO		monitor_info;
};

namespace tipupdater
{

class NotifyWindowManager: public CNMessageHandler
{
public:
	NotifyWindowManager(UpdaterDocument *document)
	{
		m_document = document;
	}

	~NotifyWindowManager()
	{
	}

	DECLARE_WND_CLASS(_T("NotifyWindowManager")) 
	// If this macro is not specified in your
	// class, ATL will generate a class name

	BEGIN_MSG_MAP(NotifyWindowManager)
		MESSAGE_HANDLER(WM_RECEIVE_SP_REGNOTIFY, OnChangedStartPage)
		MESSAGE_HANDLER(WM_RECEIVE_DS_REGNOTIFY, OnChangedDefaultSearch)
		MESSAGE_HANDLER(WM_TIMER, OnTimer)
	END_MSG_MAP()

	void Close()
	{
		KillTimer(WM_USER + 1);
	}

	void StartNotifyWindow(int timer_time)
	{
		Create();
		::SetTimer(this->m_hWnd, timer_time, WM_USER + 1, NULL);
	}

	LRESULT OnChangedStartPage(UINT nMsg, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
	{
		return CommandHelper::ExecuteCommand(_T("CreateNotifyChangedStartPageCommand"));
	}

	LRESULT OnChangedDefaultSearch(UINT nMsg, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
	{
		return CommandHelper::ExecuteCommand(_T("CreateNotifyChangedDefaultSearchEngineCommand"));
	}

	LRESULT OnTimer(UINT nMsg, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
	{
		SendShowNotifyWindowCommand();
		return TRUE;
	}

	BOOL SendShowNotifyWindowCommand()
	{
		if( NULL == m_document )
			return FALSE;

		if( TRUE == m_document->IsShowConfig() )
			return FALSE;

		if( TRUE == m_document->IsUpdating() )
			return FALSE;

		if( TRUE == m_document->GetShowNotifyWindow() )
			return FALSE;

		return CommandHelper::ExecuteCommand(_T("ShowNotifyWindowCommand"));
	}

private:
	UpdaterDocument *m_document;
};

};